@@ -8,9 +8,7 @@ from __future__ import absolute_import
 from Bio import SeqIO, SearchIO
 from Bio.Seq import Seq
 from Bio.SeqRecord import SeqRecord
-#from Bio.Blast.Applications import NcbiblastnCommandline
-#from Bio.Blast import NCBIXML
-import re, copy, sys, os, shutil, subprocess, logging, glob
+import re, os, shutil, subprocess, logging, glob
 from pathlib import Path
 from collections import defaultdict
 import pandas as pd
@@ -30,17 +28,17 @@ def dd():
 def dd_list():
 	return(defaultdict(list))
 
-def tRNAparser (gtRNAdb, tRNAscan_out, mitotRNAs, modifications_table, posttrans_mod_off, double_cca, pretrnas, local_mod):
+def tRNAparser (gtRNAdb, tRNAscan_out, mitotRNAs, plastidtRNAs, modifications_table, posttrans_mod_off, double_cca, pretrnas, local_mod):
 # tRNA sequence files parser and dictionary building
 
 	# Generate modification reference table
 	modifications = modificationParser(modifications_table)
 	temp_name = gtRNAdb.split("/")[-1]
-                
+
 	log.info("\n+" + ("-" * (len(temp_name)+24)) + "+\
 		\n| Starting analysis for {} |\
 		\n+".format(temp_name) + ("-" * (len(temp_name)+24)) + "+")
-	      
+
 	log.info("Processing tRNA sequences...")
 
 	# Build dictionary of sequences from gtRNAdb fasta
@@ -58,32 +56,44 @@ def tRNAparser (gtRNAdb, tRNAscan_out, mitotRNAs, modifications_table, posttrans
 		if not (re.search('Und', seq) or re.search('nmt', seq)):
 			if not pretrnas:
 				tRNAseq = intronRemover(Intron_dict, temp_dict, seq, posttrans_mod_off, double_cca)
+				tRNAseq = tRNAseq.upper()
 			else:
-				tRNAseq = str(temp_dict[seq].seq)
+				tRNAseq = str(temp_dict[seq].seq).upper()
 			tRNA_dict[seq]['sequence'] = tRNAseq
 			tRNA_dict[seq]['species'] = ' '.join(seq.split('_')[0:2])
 			tRNA_dict[seq]['type'] = "cytosolic"
 
-	# add mitochondrial tRNAs if given
-	if mitotRNAs:
-		temp_dict = SeqIO.to_dict(SeqIO.parse(mitotRNAs,"fasta"))
-		mito_count = defaultdict(int)
-		# read each mito tRNA, edit sequence header to match nuclear genes as above and add to tRNA_dict
+	def addExtraNucleartRNAs(trna_fasta, type, tRNA_dict, double_cca):
+		temp_dict = SeqIO.to_dict(SeqIO.parse(trna_fasta,"fasta"))
+		non_nuc_trna_count = defaultdict(int)
+		org_count = 0
+		# read each tRNA, edit sequence header to match nuclear genes as above and add to tRNA_dict
 		for seq in temp_dict:
+			org_count += 1
 			seq_parts = seq.split("|")
 			anticodon = seq_parts[4]
 			amino = re.search("[a-zA-z]+", seq_parts[3]).group(0)
-			mito_count[anticodon] += 1
-			new_seq = seq_parts[1] + "_mito_tRNA-" + amino + "-" + seq_parts[4] + "-" + str(mito_count[anticodon]) + "-1"
+			non_nuc_trna_count[anticodon] += 1
+			if type == 'mitochondrial':
+				new_seq = seq_parts[1] + "_mito_tRNA-" + amino + "-" + seq_parts[4] + "-" + str(non_nuc_trna_count[anticodon]) + "-1"
+			else:
+				new_seq = seq_parts[1] + "_plastid_tRNA-" + amino + "-" + seq_parts[4] + "-" + str(non_nuc_trna_count[anticodon]) + "-1"
 			tRNAseq = str(temp_dict[seq].seq) + "CCA" if not double_cca else str(temp_dict[seq].seq) + "CCACCA"
-			tRNA_dict[new_seq]['sequence'] = tRNAseq
-			tRNA_dict[new_seq]['type'] = 'mitochondrial'
+			tRNA_dict[new_seq]['sequence'] = tRNAseq.upper()
+			tRNA_dict[new_seq]['type'] = type
 			tRNA_dict[new_seq]['species'] = ' '.join(seq.split('_')[0:2])
 
-		num_cytosilic = len([k for k in tRNA_dict.keys() if tRNA_dict[k]['type'] == "cytosolic"])
-		num_mito = len([k for k in tRNA_dict.keys() if tRNA_dict[k]['type'] == "mitochondrial"])
+		log.info("{} ".format(org_count) + type  + " tRNA sequences imported")
+		return(tRNA_dict)
 
-		log.info("{} cytosolic and {} mitochondrial tRNA sequences imported".format(num_cytosilic, num_mito))
+	if mitotRNAs:
+		tRNA_dict = addExtraNucleartRNAs(mitotRNAs, 'mitochondrial', tRNA_dict, double_cca)
+	if plastidtRNAs:
+		tRNA_dict = addExtraNucleartRNAs(plastidtRNAs, 'plastid', tRNA_dict, double_cca)
+
+	if mitotRNAs or plastidtRNAs:
+		num_cytosilic = len([k for k in tRNA_dict.keys() if tRNA_dict[k]['type'] == "cytosolic"])
+		log.info("{} cytosolic tRNA sequences imported".format(num_cytosilic))
 
 	# Read in and parse modomics file to contain similar headers to tRNA_dict
 	# Save in new dict
@@ -95,7 +105,7 @@ def tRNAparser (gtRNAdb, tRNAscan_out, mitotRNAs, modifications_table, posttrans
 	for s in species:
 		log.info('Number of Modomics entries for {}: {}'.format(s, perSpecies_count[s]))
 
-	return(tRNA_dict,modomics_dict, species)
+	return(tRNA_dict, modomics_dict, species)
 
 def processModomics(modomics_file, fetch, species, modifications):
 
@@ -118,7 +128,7 @@ def processModomics(modomics_file, fetch, species, modifications):
 				new_anticodon = getUnmodSeq(anticodon, modifications)
 				if "N" in new_anticodon:
 					continue
-				
+
 				# Check amino acid name in modomics - set to iMet if equal to Ini to match gtRNAdb
 				amino = data['subtype']
 				if amino == 'Ini':
@@ -132,7 +142,7 @@ def processModomics(modomics_file, fetch, species, modifications):
 
 				tRNA_type = data['organellum']
 				tRNA_type = "cytosolic" if re.search("cytosol",tRNA_type) else tRNA_type
-				
+
 				sequence = data['seq'].replace('U','T').replace('-','')
 				unmod_sequence = getUnmodSeq(sequence, modifications)
 				# Return list of modified nucl and inosines indices and add to modomics_dict
@@ -140,7 +150,7 @@ def processModomics(modomics_file, fetch, species, modifications):
 				Mods = ['"', 'K', 'R', "'", 'O', 'Y', 'W', '⊆', 'X', '*', '[']
 				modPos = [i for i, x in enumerate(sequence) if x in Mods]
 				inosinePos = [i for i, x in enumerate(sequence) if x == 'I']
-				
+
 				modomics_dict[curr_id] = {'sequence':sequence,'type':tRNA_type, 'anticodon':new_anticodon, 'modified':modPos, 'unmod_sequence':unmod_sequence, 'InosinePos':inosinePos}
 
 	# build modomics_dict if data was not fetched from API - i.e. using local txt version
@@ -180,7 +190,7 @@ def processModomics(modomics_file, fetch, species, modifications):
 					tRNA_type = str(line.split('|')[4])
 					tRNA_type = "cytosolic" if re.search("cytosol",tRNA_type) else tRNA_type
 					modomics_dict[curr_id] = {'sequence':'','type':tRNA_type, 'anticodon':new_anticodon}
-			
+
 			else:
 				if not mod_species in species:
 					continue
@@ -200,7 +210,7 @@ def processModomics(modomics_file, fetch, species, modifications):
 					modomics_dict[curr_id]['modified'] = modPos
 					modomics_dict[curr_id]['unmod_sequence'] = unmod_sequence
 					modomics_dict[curr_id]["InosinePos"] = inosinePos
-		
+
 	return(modomics_dict, perSpecies_count)
 
 def getModomics(local_mod):
@@ -228,7 +238,7 @@ def getModomics(local_mod):
 
 	return modomics, fetch
 
-def modsToSNPIndex(gtRNAdb, tRNAscan_out, mitotRNAs, modifications_table, experiment_name, out_dir, double_cca, threads, snp_tolerance = False, cluster = False, cluster_id = 0.95, posttrans_mod_off = False, pretrnas = False, local_mod = False):
+def modsToSNPIndex(gtRNAdb, tRNAscan_out, mitotRNAs, plastidtRNAs, modifications_table, experiment_name, out_dir, double_cca, threads, snp_tolerance = False, cluster = False, cluster_id = 0.95, posttrans_mod_off = False, pretrnas = False, local_mod = False, search='usearch'):
 # Builds SNP index needed for GSNAP based on modificaiton data for each tRNA and clusters tRNAs
 
 	nomatch_count = 0
@@ -240,7 +250,7 @@ def modsToSNPIndex(gtRNAdb, tRNAscan_out, mitotRNAs, modifications_table, experi
 	anticodon_list = list()
 	tRNAbed = open(out_dir + experiment_name + "_maturetRNA.bed","w")
 	# generate modomics_dict and tRNA_dict
-	tRNA_dict, modomics_dict, species = tRNAparser(gtRNAdb, tRNAscan_out, mitotRNAs, modifications_table, posttrans_mod_off, double_cca, pretrnas, local_mod)
+	tRNA_dict, modomics_dict, species = tRNAparser(gtRNAdb, tRNAscan_out, mitotRNAs, plastidtRNAs, modifications_table, posttrans_mod_off, double_cca, pretrnas, local_mod)
 	temp_dir = out_dir + "/tmp/"
 
 	try:
@@ -259,7 +269,7 @@ def modsToSNPIndex(gtRNAdb, tRNAscan_out, mitotRNAs, modifications_table, experi
 		for seq in tRNA_dict:
 			tempSeqs.write(">" + seq + "\n" + tRNA_dict[seq]['sequence'] + "\n")
 
-	aligntRNA(tempSeqs.name, out_dir)
+	aligntRNA(tempSeqs.name, out_dir, threads)
 	extra_cca = extraCCA()
 
 	for record in extra_cca:
@@ -271,7 +281,7 @@ def modsToSNPIndex(gtRNAdb, tRNAscan_out, mitotRNAs, modifications_table, experi
 
 	log.info("\n+------------------------+ \
 		\n| Beginning SNP indexing |\
-		\n+------------------------+")	
+		\n+------------------------+")
 
 	for seq in tRNA_dict:
 		# Initialise list of modified sites for each tRNA
@@ -287,18 +297,15 @@ def modsToSNPIndex(gtRNAdb, tRNAscan_out, mitotRNAs, modifications_table, experi
 		match = {k:v for k,v in modomics_dict.items() if re.match("^" + v['anticodon'] + "+$", anticodon) and tRNA_dict[seq]['type'] == v['type']}
 		if len(match) >= 1:
 			temp_matchFasta = open(temp_dir + "modomicsMatch.fasta","w")
-			for i in match:	
+			for i in match:
 				temp_matchFasta.write(">" + i + "\n" + match[i]['unmod_sequence'] + "\n")
 			temp_matchFasta.close()
 
 			#blast
 			blastn_cmd = ["blastn", "-query", temp_tRNAFasta.name, "-subject", temp_matchFasta.name, "-task", "blastn-short", "-out", temp_dir + "blast_temp.xml", "-outfmt", "5", "-num_threads", str(threads)]
 			subprocess.check_call(blastn_cmd, stdout = subprocess.DEVNULL, stderr=subprocess.DEVNULL)
-			#blastn_cline = NcbiblastnCommandline(query = temp_tRNAFasta.name, subject = temp_matchFasta.name, task = 'blastn-short', out = temp_dir + "blast_temp.xml", outfmt = 5)
-			#blastn_cline()
 
-			#parse XML result and store hit with highest bitscore	
-			#blast_record = NCBIXML.read(open(temp_dir + "blast_temp.xml","r"))
+			#parse XML result and store hit with highest bitscore
 			blast_record = SearchIO.read(temp_dir + "blast_temp.xml", "blast-xml")
 			maxbit = 0
 			tophit = ''
@@ -307,12 +314,18 @@ def modsToSNPIndex(gtRNAdb, tRNAscan_out, mitotRNAs, modifications_table, experi
 					if (hsp.bitscore > maxbit) and (hsp.aln_span / blast_record.seq_len == 1) and (hsp.ident_num / blast_record.seq_len == 1):
 						maxbit = hsp.bitscore
 						tophit = hit.id.split(' ')[0]
-			
+						# track start position of modomics hits to modify mods and inosine positions below
+						hit_start = hsp.hit_start
+
 			# return list of all modified positions for the match as long as there is only 1, add to tRNA_dict
 			if tophit:
 				match_count += 1
-				tRNA_dict[seq]['modified'] = match[tophit]['modified']
-				tRNA_dict[seq]['InosinePos'] = match[tophit]['InosinePos']
+				# some Modomics sequences are weird and have additional 5' nucleotides
+                # if the hit match starts at pos 0 then log all mods and inosines as normal
+                # if not, then the start position of the modomics hit relative to query needs to be accounted for
+                # wrt mods and inosine positions in the tRNA_dict sequence
+				tRNA_dict[seq]['modified'] = match[tophit]['modified'] if hit_start == 0 else [x - hit_start for x in match[tophit]['modified']]
+				tRNA_dict[seq]['InosinePos'] = match[tophit]['InosinePos'] if hit_start == 0 else [x - hit_start for x in match[tophit]['InosinePos']]
 			elif len(tophit) == 0:
 				nomatch_count += 1
 		if len(match) == 0:
@@ -331,12 +344,12 @@ def modsToSNPIndex(gtRNAdb, tRNAscan_out, mitotRNAs, modifications_table, experi
 	with open(str(out_dir + experiment_name + '_tRNATranscripts.fa'), "w") as temptRNATranscripts:
 		SeqIO.write(seq_records.values(), temptRNATranscripts, "fasta")
 
-	# if clustering is not activated then write full gff and report on total SNPs written 
+	# if clustering is not activated then write full gff and report on total SNPs written
 	if not cluster:
 		coverage_bed = tRNAbed.name
 		mod_lists = defaultdict(list)
 		Inosine_lists = defaultdict(list)
-		with open(out_dir + experiment_name + "_tRNA.gff","w") as tRNAgff, open(out_dir + experiment_name + "isoacceptorInfo.txt","w") as isoacceptorInfo:	
+		with open(out_dir + experiment_name + "_tRNA.gff","w") as tRNAgff, open(out_dir + experiment_name + "isoacceptorInfo.txt","w") as isoacceptorInfo:
 			isoacceptor_dict = defaultdict(int)
 			isoacceptorInfo.write("Isoacceptor\tsize\n")
 			for seq in tRNA_dict:
@@ -348,7 +361,7 @@ def modsToSNPIndex(gtRNAdb, tRNAscan_out, mitotRNAs, modifications_table, experi
 			for key, value in isoacceptor_dict.items():
 				isoacceptorInfo.write(key + "\t" + str(value) + "\n")
 		# generate Stockholm alignment file for all tRNA transcripts and parse additional mods file
-		aligntRNA(temptRNATranscripts.name, out_dir)
+		aligntRNA(temptRNATranscripts.name, out_dir, threads)
 		additionalMods, additionalInosines = additionalModsParser(species, out_dir)
 		# add additional SNPs from extra file to list of modified positions, and ensure non-redundancy with set()
 		# index SNPs
@@ -428,8 +441,9 @@ def modsToSNPIndex(gtRNAdb, tRNAscan_out, mitotRNAs, modifications_table, experi
 				for sequence in seq_set:
 					anticodon_seqs.write(">" + sequence + "\n" + seq_set[sequence]['sequence'] + "\n")
 			# run usearch on each anticodon sequence fatsa to cluster
-			cluster_cmd = ["usearch", "-cluster_fast", temp_dir + anticodon + "_allseqs.fa", "-id", str(cluster_id), "-sizeout" ,"-centroids", temp_dir + anticodon + "_centroids.fa", "-uc", temp_dir + anticodon + "_clusters.uc"]
-			#cluster_cmd = ["usearch", "-cluster_smallmem", temp_dir + anticodon + "_allseqs.fa", "-id", str(cluster_id), "--sortedby", "other" ,"-sizeout" ,"-centroids", temp_dir + anticodon + "_centroids.fa", "-uc", temp_dir + anticodon + "_clusters.uc"]			#cluster_cmd = "usearch -cluster_fast " + temp_dir + anticodon + "_allseqs.fa -sort length -id " + str(cluster_id) + " -centroids " + temp_dir + anticodon + "_centroids.fa -uc " + temp_dir + anticodon + "_clusters.uc &> /dev/null"
+			# -fulldp uses non-heuristic ful dynamic programming for best alignment
+			# -minsl controls minimum value of shorter_seq_length / longer_seq_length to prevent very different lenght seqs from clustering
+			cluster_cmd = ["usearch", "-cluster_fast", temp_dir + anticodon + "_allseqs.fa", "-minsl", "0.98", "-fulldp", "-id", str(cluster_id), "-sizeout" ,"-centroids", temp_dir + anticodon + "_centroids.fa", "-uc", temp_dir + anticodon + "_clusters.uc"]
 			subprocess.check_call(cluster_cmd, stdout = subprocess.DEVNULL, stderr=subprocess.DEVNULL)
 			# sort clusters by size (i.e. number of members in cluster)
 			sort_cmd = ["usearch", "-sortbysize", temp_dir + anticodon + "_centroids.fa", "-fastaout", temp_dir + anticodon + "_centroids_sort.fa"]
@@ -445,7 +459,7 @@ def modsToSNPIndex(gtRNAdb, tRNAscan_out, mitotRNAs, modifications_table, experi
 		centroids = SeqIO.parse(temp_dir + "all_centroids.fa", "fasta")
 		for centroid in centroids:
 			centroid.id = centroid.id.split(";")[0]
-			final_centroids[centroid.id] = SeqRecord(Seq(str(centroid.seq).upper()), id = centroid.id) 
+			final_centroids[centroid.id] = SeqRecord(Seq(str(centroid.seq).upper()), id = centroid.id)
 
 		# read cluster files, get nonredudant set of mod positions of all members of a cluster, create snp_records for writing SNP index
 		cluster_pathlist = Path(temp_dir).glob("**/*_clusters.uc")
@@ -477,7 +491,7 @@ def modsToSNPIndex(gtRNAdb, tRNAscan_out, mitotRNAs, modifications_table, experi
 						clusterbed.write(cluster_name + "\t0\t" + str(len(tRNA_dict[cluster_name]['sequence'])) + "\t" + cluster_name + "\t1000\t+\n" )
 						clustergff.write(cluster_name + "\ttRNAseq\texon\t1\t" + str(len(tRNA_dict[cluster_name]['sequence'])) + "\t.\t+\t0\tgene_id '" + cluster_name + "'\n")
 						cluster_dict[cluster_name].append(cluster_name)
-				
+
 					# Handle members of clusters
 					elif line.split("\t")[0] == "H":
 						member_name = line.split("\t")[8].split(";")[0]
@@ -488,7 +502,7 @@ def modsToSNPIndex(gtRNAdb, tRNAscan_out, mitotRNAs, modifications_table, experi
 							mod_lists[cluster_name] = list(set(mod_lists[cluster_name] + tRNA_dict[member_name]["modified"]))
 							Inosine_lists[cluster_name] = list(set(Inosine_lists[cluster_name] + tRNA_dict[member_name]["InosinePos"]))
 							cluster_dict[cluster_name].append(member_name)
-						
+
 						# if there are insertions or deletions in the centroid, edit member or centroid sequences to ignore these positions
 						# and edit modified positions list in order to make non-redundant positions list, similar to next else statement
 						elif re.search("[ID]", compr_aln):
@@ -503,7 +517,7 @@ def modsToSNPIndex(gtRNAdb, tRNAscan_out, mitotRNAs, modifications_table, experi
 							aln_list = list(filter(None, aln_list))
 
 							for phrase in aln_list:
-								
+
 								if ("M" in phrase) and (phrase.split("M")[0] != ""):
 									pos += int(phrase.split("M")[0])
 								elif ("M" in phrase) and (phrase.split("M")[0] == ""):
@@ -642,18 +656,18 @@ def modsToSNPIndex(gtRNAdb, tRNAscan_out, mitotRNAs, modifications_table, experi
 			SeqIO.write(final_centroids.values(), clusterTranscripts, "fasta")
 
 		if total_snps == 0:
-			snp_tolerance = False		
+			snp_tolerance = False
 
 		log.info("{:,} modifications/cluster mismatches written to SNP index".format(total_snps))
-		log.info("{:,} A to G replacements in reference sequences for inosine modifications".format(total_inosines))		
-	
-	# write outputs for indexing 
+		log.info("{:,} A to G replacements in reference sequences for inosine modifications".format(total_inosines))
+
+	# write outputs for indexing
 	with open(out_dir + experiment_name + "_modificationSNPs.txt", "w") as snp_file:
 		for item in snp_records:
 			snp_file.write('{}\n'.format(item))
-	
+
 	shutil.rmtree(temp_dir)
-	
+
 	# Return coverage_bed (either tRNAbed or clusterbed depending on --cluster) for coverage calculation method
 	return(coverage_bed, snp_tolerance, mismatch_dict, insert_dict, del_dict, mod_lists, Inosine_lists, Inosine_clusters, tRNA_dict, cluster_dict, cluster_perPos_mismatchMembers)
 
@@ -662,7 +676,7 @@ def newModsParser(out_dir, experiment_name, new_mods_list, new_Inosines, mod_lis
 
 	log.info("\n+------------------+ \
 		\n| Parsing new mods |\
-		\n+------------------+")	
+		\n+------------------+")
 
 	new_snps_num = 0
 	new_inosines = 0
@@ -714,14 +728,14 @@ def newModsParser(out_dir, experiment_name, new_mods_list, new_Inosines, mod_lis
 			tRNA_ref = out_dir + experiment_name + '_clusterTranscripts.fa'
 		else:
 			tRNA_ref = out_dir + experiment_name + '_tRNATranscripts.fa'
-		
-		tRNA_seqs = SeqIO.to_dict(SeqIO.parse(tRNA_ref, 'fasta'))	
+
+		tRNA_seqs = SeqIO.to_dict(SeqIO.parse(tRNA_ref, 'fasta'))
 
 		# rewrite tRNA transcript reference
 		with open(tRNA_ref, "w") as transcript_fasta:
 			SeqIO.write(tRNA_seqs.values(), transcript_fasta, "fasta")
-				
-		log.info("{:,} modifications written to SNP index".format(total_snps))	
+
+		log.info("{:,} modifications written to SNP index".format(total_snps))
 
 	return(Inosine_clusters, snp_tolerance, tRNA_dict, mod_lists, Inosine_lists)
 
@@ -758,13 +772,13 @@ def additionalModsParser(input_species, out_dir):
 	# for each additional modification in dictionary, define mod site based on conserved location relative to structural features
 	for isodecoder, data in additionalMods.items():
 		if data['type'] == "mitochondrial":
-			clusters = [key for key, value in tRNA_struct_nogap.items() if isodecoder in key and 'nmt' not in key and "mito" in key]
+			clusters = [key for key in tRNA_struct_nogap.keys() if isodecoder in key and 'nmt' not in key and "mito" in key]
 		else:
-			clusters = [key for key, value in tRNA_struct_nogap.items() if isodecoder in key and 'nmt' not in key and "mito" not in key]
+			clusters = [key for key in tRNA_struct_nogap.keys() if isodecoder in key and 'nmt' not in key and "mito" not in key]
 		for cluster in clusters:
 			no_gap_struct = [value for key, value in tRNA_struct_nogap.items() if key == cluster and 'nmt' not in key]
 			if not no_gap_struct: # test if struct is empty, i.e. if isodecoder from additional mods does not exist in tRNA dictionary
-				continue		
+				continue
 			anticodon = clusterAnticodon(cons_anticodon, cluster)
 
 			for mod in data['mods']:
@@ -798,7 +812,7 @@ def getModSite(cluster, cons_pos, cons_pos_dict, tRNA_struct, tRNA_struct_nogap)
 		mod_site = all_struct_element_list_nogap[index_struct_element]
 	else:
 		mod_site = 'NA'
-	
+
 	return(mod_site)
 
 def generateGSNAPIndices(species, name, out_dir, map_round, snp_tolerance = False, cluster = False):
@@ -816,19 +830,19 @@ def generateGSNAPIndices(species, name, out_dir, map_round, snp_tolerance = Fals
 
 	genome_index_path = out_dir + species + "_tRNAgenome"
 	genome_index_name = genome_index_path.split("/")[-1]
-	
+
 	try:
 		os.mkdir(genome_index_path)
 	except FileExistsError:
 		log.warning("Genome index folder found! Rebuilding index anyway...")
-	
+
 	if cluster:
 		genome_file = out_dir + name + "_clusterTranscripts.fa"
 	else:
 		genome_file = out_dir + name + "_tRNATranscripts.fa"
 
 	index_cmd = ["gmap_build", "-q", "1", "-D", out_dir, "-d", species + "_tRNAgenome", genome_file]
-	subprocess.check_call(index_cmd, stderr = open(out_dir + "genomeindex.log", "w"), stdout = subprocess.DEVNULL) 
+	subprocess.check_call(index_cmd, stderr = open(out_dir + "genomeindex.log", "w"), stdout = subprocess.DEVNULL)
 	log.info("Genome indices done...")
 
 	snp_index_path = out_dir + species + "snp_index"
@@ -928,7 +942,7 @@ def initIntronDict(tRNAscan_out):
 # Build dictionary of intron locations
 
 	Intron_dict = {}
-	tRNAscan = open(tRNAscan_out, 'r') 
+	tRNAscan = open(tRNAscan_out, 'r')
 	intron_count = 0
 	for line in tRNAscan:
 		if line.startswith("chr"):
@@ -976,65 +990,21 @@ def intronRemover (Intron_dict, seqIO_dict, seqIO_record, posttrans_mod_off, dou
 
 	return(seq)
 
-def countReads(input_counts, out_dir, isodecoder_sizes, clustering, tRNA_dict, clusterInfo):
-
+def countsAnticodon(input_counts, out_dir):
 	# Counts per anticodon
-	count_dict_anticodon = defaultdict(lambda: defaultdict(int))
-	count_dict_isodecoder = defaultdict(lambda: defaultdict(int))
 
-	with open(input_counts, "r") as counts_file:
-		for line in counts_file:
-			line = line.strip()
-			if not line.startswith("#"):
-				if line.startswith("isodecoder"):
-					sample_list = [samples for samples in line.split("\t")[1:-3]]
-				else:
-					isodecoder = line.split("\t")[0]
-					anticodon = "-".join(isodecoder.split("-")[:-1]) if not "chr" in isodecoder else "-".join(isodecoder.split("-")[:-2])
-					# replace "tRX" with "tRNA" in anticodon names so that low confidence tRX genes also get summed with their respective anticodon
-					anticodon = anticodon.replace("tRX", "tRNA")
-					# replace Mut in the case of custom mutation references so that these counts get added to the corresponsing anticodon
-					anticodon = anticodon.replace("Mut", "")
-					col = 1
-					for sample in sample_list:
-						count_dict_anticodon[anticodon][sample] += float(line.split("\t")[col])
-						if not clustering:
-							count_dict_isodecoder[isodecoder][sample] = float(line.split("\t")[col])
-						col += 1
-
-	count_anticodon_pd = pd.DataFrame.from_dict(count_dict_anticodon, orient='index')
-	count_anticodon_pd.index.name = 'Anticodon'
-	count_anticodon_pd.to_csv(out_dir + 'Anticodon_counts_raw.txt', sep = '\t')
-
-	if not clustering:
-		new_count_isodecoder = defaultdict(lambda: defaultdict(int))
-		for isodecoder in isodecoder_sizes:
-			sameSeq = [tRNAs for tRNAs in tRNA_dict.keys() if tRNA_dict[tRNAs]['sequence'] == tRNA_dict[isodecoder]['sequence']]
-			for i in sameSeq:
-				i = "-".join(i.split("-")[:-1])
-				for lib in count_dict_isodecoder[isodecoder].keys():
-					new_count_isodecoder[isodecoder][lib] += count_dict_isodecoder[i][lib]
-
-		count_isodecoder_pd = pd.DataFrame.from_dict(new_count_isodecoder, orient='index')
-		count_isodecoder_pd.index.name = 'isodecoder'
-		count_isodecoder_pd['Single_isodecoder'] = "True"
-
-		isodecoder_sizes_short = defaultdict()
-		for iso, size in isodecoder_sizes.items():
-			if not "chr" in iso:
-				short = "-".join(iso.split("-")[:-1])
-			else:
-				short = iso
-			isodecoder_sizes_short[short] = size
-		for cluster in count_isodecoder_pd.index:
-			count_isodecoder_pd.at[cluster, 'size'] = isodecoder_sizes_short[cluster]
-		count_isodecoder_pd = count_isodecoder_pd.join(clusterInfo)
-		count_isodecoder_pd.to_csv(out_dir + 'Isodecoder_counts.txt', sep = '\t')
+	input_counts['Anticodon'] = input_counts.isodecoder.str.split("-").str[:-1].str.join("-")
+	# replace "tRX" with "tRNA" in anticodon names so that low confidence tRX genes also get summed with their respective anticodon
+	input_counts["Anticodon"] = input_counts.Anticodon.str.replace("tRX","tRNA")
+	# replace Mut in the case of custom mutation references so that these counts get added to the corresponsing anticodon
+	input_counts["Anticodon"] = input_counts.Anticodon.str.replace("Mut","")
+	input_counts= input_counts.groupby(["Anticodon"]).agg(sum).reset_index()
+	input_counts.to_csv(out_dir + "Anticodon_counts_raw.txt", sep = "\t", index = False)
 
 	log.info("** Read counts per anticodon saved to " + out_dir + "counts/Anticodon_counts_raw.txt **")
 
 def tidyFiles (out_dir, cca):
-	
+
 	os.mkdir(out_dir + "annotation/")
 	os.mkdir(out_dir + "align/")
 	os.mkdir(out_dir + "indices/")
@@ -1045,7 +1015,7 @@ def tidyFiles (out_dir, cca):
 
 	for file in files:
 		full_file = out_dir + file
-		if (file.endswith("bed") or file.endswith("stk") or file.endswith("gff") or file.endswith("fa") or "cm.log" in file or "clusterInfo" in file or "isoacceptorInfo" in file or "isodecoderInfo" in file or "modificationSNPs" in file):
+		if (file.endswith("bed") or file.endswith("stk") or file.endswith("gff") or file.endswith("fa") or "cm.log" in file or "clusterInfo" in file or "isoacceptorInfo" in file or "isodecoderInfo" in file or "unsplitClusterInfo" in file or "modificationSNPs" in file):
 			shutil.move(full_file, out_dir + "annotation")
 		if (file.endswith("tRNAgenome") or file.endswith("index") or "index.log" in file):
 			shutil.move(full_file, out_dir + "indices")
